@@ -1,21 +1,17 @@
 #! /usr/bin/python3
-# -*- coding: UTF-8 -*-
-try:
-    from setuptools import setup, find_packages
-except ImportError:
-    exit()
+from distutils.core import setup
 
 setup(name='Foo',
-      version=0.1,
-      description="Foo to rule them all",
+      version='0.2',
+      description="package with public modules only",
       long_description="TODO",
       keywords='foo bar baz',
       author='Piotr Ożarowski',
       author_email='piotr@debian.org',
       url='http://www.debian.org/',
       license='MIT',
-      package_dir={'': 'lib'},
-      packages=find_packages('lib/'),
+      packages = ['foo'],
+      package_dir = {'foo': 'lib/foo'},
       package_data = {'foo': ['jquery.js']},
       zip_safe=False,
       install_requires = ['Mako', 'Baz [extras]'],
